@@ -349,10 +349,6 @@ get_mod(<<"tzo">>, <<"urn:xmpp:time">>) -> xep0202;
 get_mod(<<"unsupported-info">>,
         <<"urn:xmpp:jingle:errors:1">>) ->
     xep0166;
-get_mod(<<"query">>, <<"jabber:iq:version">>) ->
-    xep0092;
-get_mod(<<"archived">>, <<"urn:xmpp:mam:tmp">>) ->
-    xep0313;
 get_mod(<<"nick">>, <<"urn:xmpp:mix:core:1">>) ->
     xep0369;
 get_mod(<<"next">>,
@@ -466,8 +462,6 @@ get_mod(<<"no-permanent-storage">>,
 get_mod(<<"unsupported-applications">>,
         <<"urn:xmpp:jingle:1">>) ->
     xep0166;
-get_mod(<<"text">>, <<"urn:xmpp:reporting:0">>) ->
-    xep0377;
 get_mod(<<"credentials-expired">>,
         <<"urn:ietf:params:xml:ns:xmpp-sasl">>) ->
     rfc6120;
@@ -678,6 +672,9 @@ get_mod(<<"decline">>, <<"urn:xmpp:jingle:1">>) ->
 get_mod(<<"connection">>,
         <<"urn:xmpp:serverinfo:0">>) ->
     xep0485;
+get_mod(<<"sub">>,
+        <<"urn:xmpp:features:pre-approval">>) ->
+    rfc6121;
 get_mod(<<"key">>, <<"jabber:iq:register">>) -> xep0077;
 get_mod(<<"unsupported">>,
         <<"http://jabber.org/protocol/pubsub#errors">>) ->
@@ -694,6 +691,8 @@ get_mod(<<"query">>, <<"jabber:iq:register">>) ->
     xep0077;
 get_mod(<<"CLASS">>, <<"vcard-temp">>) -> xep0054;
 get_mod(<<"result">>, <<"urn:xmpp:mam:2">>) -> xep0313;
+get_mod(<<"register">>, <<"urn:xmpp:ibr-token:0">>) ->
+    xep0445;
 get_mod(<<"purge">>,
         <<"http://jabber.org/protocol/pubsub#event">>) ->
     xep0060;
@@ -724,6 +723,8 @@ get_mod(<<"close">>,
     xep0047;
 get_mod(<<"x509-csr">>, <<"urn:xmpp:x509:0">>) ->
     xep0417;
+get_mod(<<"report">>, <<"urn:xmpp:reporting:1">>) ->
+    xep0377;
 get_mod(<<"internal-server-error">>,
         <<"urn:ietf:params:xml:ns:xmpp-stanzas">>) ->
     rfc6120;
@@ -817,6 +818,9 @@ get_mod(<<"destroy">>,
     xep0045;
 get_mod(<<"subscribe">>, <<"urn:xmpp:mix:core:1">>) ->
     xep0369;
+get_mod(<<"referenced-stanza">>,
+        <<"urn:xmpp:sid:0">>) ->
+    xep0359;
 get_mod(<<"compress">>,
         <<"http://jabber.org/protocol/compress">>) ->
     xep0138;
@@ -852,6 +856,8 @@ get_mod(<<"connectivity-error">>,
 get_mod(<<"retracted">>,
         <<"urn:xmpp:message-retract:1">>) ->
     xep0424;
+get_mod(<<"preauth">>, <<"urn:xmpp:pars:0">>) ->
+    xep0379;
 get_mod(<<"stream:features">>, <<"jabber:server">>) ->
     rfc6120;
 get_mod(<<"request">>,
@@ -936,8 +942,6 @@ get_mod(<<"fetch">>,
 get_mod(<<"failed-transport">>,
         <<"urn:xmpp:jingle:1">>) ->
     xep0166;
-get_mod(<<"abuse">>, <<"urn:xmpp:reporting:0">>) ->
-    xep0377;
 get_mod(<<"state">>, <<"jabber:iq:register">>) ->
     xep0077;
 get_mod(<<"utc">>, <<"urn:xmpp:time">>) -> xep0202;
@@ -1028,6 +1032,8 @@ get_mod(<<"enable">>, <<"urn:xmpp:sm:3">>) -> xep0198;
 get_mod(<<"size">>,
         <<"eu:siacs:conversations:http:upload">>) ->
     xep0363;
+get_mod(<<"text">>, <<"urn:xmpp:reporting:1">>) ->
+    xep0377;
 get_mod(<<"registration-required">>,
         <<"urn:ietf:params:xml:ns:xmpp-stanzas">>) ->
     rfc6120;
@@ -1075,8 +1081,6 @@ get_mod(<<"text">>, <<"jabber:iq:register">>) ->
     xep0077;
 get_mod(<<"private">>, <<"urn:xmpp:carbons:2">>) ->
     xep0280;
-get_mod(<<"spam">>, <<"urn:xmpp:reporting:0">>) ->
-    xep0377;
 get_mod(<<"show">>, <<"jabber:component:accept">>) ->
     rfc6120;
 get_mod(<<"PAGER">>, <<"vcard-temp">>) -> xep0054;
@@ -1645,8 +1649,6 @@ get_mod(<<"software">>, <<"urn:xmpp:sasl:2">>) ->
 get_mod(<<"task-data">>, <<"urn:xmpp:sasl:2">>) ->
     xep0388;
 get_mod(<<"inline">>, <<"urn:xmpp:bind:0">>) -> xep0386;
-get_mod(<<"report">>, <<"urn:xmpp:reporting:0">>) ->
-    xep0377;
 get_mod(<<"item-not-found">>,
         <<"urn:ietf:params:xml:ns:xmpp-stanzas">>) ->
     rfc6120;
@@ -1776,6 +1778,10 @@ get_mod(<<"submission-id">>,
         <<"urn:xmpp:mix:core:0">>) ->
     xep0369;
 get_mod(<<"text">>, <<"urn:xmpp:sasl:2">>) -> xep0388;
+get_mod(<<"query">>, <<"jabber:iq:version">>) ->
+    xep0092;
+get_mod(<<"archived">>, <<"urn:xmpp:mam:tmp">>) ->
+    xep0313;
 get_mod(Name, XMLNS) ->
     xmpp_codec_external:lookup(Name, XMLNS).
 
@@ -1817,6 +1823,7 @@ get_mod({disco_items, _, _, _}) -> xep0030;
 get_mod({vcard_xupdate, _}) -> xep0153;
 get_mod({sasl2_challenge, _}) -> xep0388;
 get_mod({bind2_feature, _}) -> xep0386;
+get_mod({feature_register_ibr_token}) -> xep0445;
 get_mod({block_item, _, _}) -> xep0191;
 get_mod({message, _, _, _, _, _, _, _, _, _, _}) ->
     rfc6120;
@@ -1869,7 +1876,6 @@ get_mod({mam_archived, _, _}) -> xep0313;
 get_mod({mix_participant, _, _}) -> xep0369;
 get_mod({delegated, _, _}) -> xep0355;
 get_mod({text, _, _}) -> xep0234;
-get_mod({muc_hat, _, _}) -> xep0317;
 get_mod({scram_upgrade_salt, _, _}) -> xep0480;
 get_mod({xmpp_session, _}) -> rfc3921;
 get_mod({ping}) -> xep0199;
@@ -1922,18 +1928,15 @@ get_mod({fasten_apply_to, _, _, _}) -> xep0422;
 get_mod({mix_destroy, _, _}) -> xep0369;
 get_mod({media_uri, _, _}) -> xep0221;
 get_mod({jingle_error, _}) -> xep0166;
+get_mod({feature_pre_approval}) -> rfc6121;
 get_mod({sasl_success, _}) -> rfc6120;
 get_mod({compress, _}) -> xep0138;
 get_mod({xdata_field, _, _, _, _, _, _, _, _}) ->
     xep0004;
-get_mod({muc_subscriptions, _}) -> p1_mucsub;
-get_mod({mix, _, _, _, _}) -> xep0369;
-get_mod({addresses, _}) -> xep0033;
 get_mod({adhoc_command, _, _, _, _, _, _, _, _}) ->
     xep0050;
 get_mod({media, _, _, _}) -> xep0221;
 get_mod({oob_x, _, _, _, _}) -> xep0066;
-get_mod({ibb_data, _, _, _}) -> xep0047;
 get_mod({identity, _, _, _, _}) -> xep0030;
 get_mod({redirect, _}) -> rfc6120;
 get_mod({muc_history, _, _, _, _}) -> xep0045;
@@ -1994,6 +1997,7 @@ get_mod({offline_item, _, _}) -> xep0013;
 get_mod({db_verify, _, _, _, _, _, _}) -> xep0220;
 get_mod({upload_slot, _, _, _}) -> xep0363;
 get_mod({jingle_ibb_transport, _, _, _}) -> xep0261;
+get_mod({muc_hat, _, _, _}) -> xep0317;
 get_mod({message_moderated, _, _, _}) -> xep0425;
 get_mod({muc_decline, _, _, _}) -> xep0045;
 get_mod({sm_enable, _, _, _}) -> xep0198;
@@ -2015,9 +2019,9 @@ get_mod({mix_update_subscription, _, _, _, _}) ->
     xep0369;
 get_mod({upload_retry, _}) -> xep0363;
 get_mod({x509_register}) -> xep0417;
-get_mod({roster_item, _, _, _, _, _, _}) -> rfc6121;
 get_mod({unified_push_push, _, _, _}) -> unifiedpush;
 get_mod({rsm_set, _, _, _, _, _, _, _}) -> xep0059;
+get_mod({referenced_stanza, _, _}) -> xep0359;
 get_mod({avatar_meta, _, _}) -> xep0084;
 get_mod({roster_query, _, _, _}) -> rfc6121;
 get_mod({unblock, _}) -> xep0191;
@@ -2053,6 +2057,7 @@ get_mod({mix_client_join, _, _, _}) -> xep0405;
 get_mod({jingle_reason, _, _, _}) -> xep0166;
 get_mod({ps_event, _, _, _, _, _, _}) -> xep0060;
 get_mod({privileged_iq, _}) -> xep0356;
+get_mod({roster_item, _, _, _, _, _, _, _}) -> rfc6121;
 get_mod({sasl_mechanisms, _}) -> rfc6120;
 get_mod({starttls, _}) -> rfc6120;
 get_mod({stream_start, _, _, _, _, _, _, _, _}) ->
@@ -2097,6 +2102,7 @@ get_mod({message_moderate, _, _, _}) -> xep0425;
 get_mod({sasl_channel_binding, _}) -> xep0440;
 get_mod({db_result, _, _, _, _, _}) -> xep0220;
 get_mod({scram_upgrade_hash, _}) -> xep0480;
+get_mod({preauth, _}) -> xep0379;
 get_mod({bookmark_conference, _, _, _, _, _}) ->
     xep0048;
 get_mod({vcard_name, _, _, _, _, _}) -> xep0054;
@@ -2169,4 +2175,8 @@ get_mod({upload_slot_0, _, _, _}) -> xep0363;
 get_mod({delegation_query, _, _}) -> xep0355;
 get_mod({jingle_s5b_candidate, _, _, _, _, _, _}) ->
     xep0260;
+get_mod({muc_subscriptions, _}) -> p1_mucsub;
+get_mod({mix, _, _, _, _}) -> xep0369;
+get_mod({addresses, _}) -> xep0033;
+get_mod({ibb_data, _, _, _}) -> xep0047;
 get_mod(Record) -> xmpp_codec_external:lookup(Record).
